<?php

namespace ipl\Web\Compat;

use ipl\Web\FormDecorator\IcingaFormDecorator;

/**
 * Compat form element decorator based on div elements
 *
 * @deprecated Use {@see \ipl\Web\FormDecorator\IcingaFormDecorator} instead
 */
class CompatDecorator extends IcingaFormDecorator
{
}
