.suggestion-element-group {
  display: inline-flex;

  .suggestion-element,
  .suggestion-element-icon {
    line-height: normal;
    height: 2.25em;
    padding: 0.5em;
    background-color: var(--default-input-bg, @default-input-bg);
    color: var(--default-text-color, @default-text-color);
  }

  .suggestion-element {
    border: none;
    outline: none;
    border-radius: 0 0.25em 0.25em 0;
  }

  .suggestion-element-icon {
    padding-right: 0;
    border-radius: 0.25em 0 0 0.25em;
  }

  &:focus-within {
    border-radius: 0.25em;
    outline: 3px solid var(--default-input-outline-color, @default-input-outline-color);
    outline-offset: 1px;
  }
}
