<?php return array(
    'root' => array(
        'name' => 'icinga/icinga-php-library',
        'pretty_version' => 'dev-main',
        'version' => 'dev-main',
        'reference' => '2c7b1e3973a034b226c6a20392392cbe6be86180',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => true,
    ),
    'versions' => array(
        'brick/math' => array(
            'pretty_version' => '0.14.8',
            'version' => '0.14.8.0',
            'reference' => '63422359a44b7f06cae63c3b429b59e8efcc0629',
            'type' => 'library',
            'install_path' => __DIR__ . '/../brick/math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/collections' => array(
            'pretty_version' => '2.6.0',
            'version' => '2.6.0.0',
            'reference' => '7713da39d8e237f28411d6a616a3dce5e20d5de2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/collections',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/deprecations' => array(
            'pretty_version' => '1.1.6',
            'version' => '1.1.6.0',
            'reference' => 'd4fe3e6fd9bb9e72557a19674f44d8ac7db4c6ca',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/deprecations',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'dragonmantank/cron-expression' => array(
            'pretty_version' => 'v3.6.0',
            'version' => '3.6.0.0',
            'reference' => 'd61a8a9604ec1f8c3d150d09db6ce98b32675013',
            'type' => 'library',
            'install_path' => __DIR__ . '/../dragonmantank/cron-expression',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'evenement/evenement' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => '0a16b0d71ab13284339abb99d9d2bd813640efbc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../evenement/evenement',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fortawesome/font-awesome' => array(
            'pretty_version' => '6.7.2',
            'version' => '6.7.2.0',
            'reference' => 'af620534bfc3c2d4cbefcfeec29603bbe7809e64',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fortawesome/font-awesome',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.9.0',
            'version' => '2.9.0.0',
            'reference' => '7d0ed42f28e42d61352a7a79de682e5e67fec884',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icinga/icinga-php-library' => array(
            'pretty_version' => 'dev-main',
            'version' => 'dev-main',
            'reference' => '2c7b1e3973a034b226c6a20392392cbe6be86180',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icinga/zf1' => array(
            'pretty_version' => 'v2.0.1',
            'version' => '2.0.1.0',
            'reference' => '7acc93188de48501cccadb7f223c0aebeec5bf57',
            'type' => 'library',
            'install_path' => __DIR__ . '/../icinga/zf1',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/html' => array(
            'pretty_version' => 'v0.10.2',
            'version' => '0.10.2.0',
            'reference' => '131cf2b0cc2e05b2fb908e67634fba715778660c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/html',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/i18n' => array(
            'pretty_version' => 'v1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'ac4ce4fc006723fcc45df4566816b205554dc0fc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/i18n',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/orm' => array(
            'pretty_version' => 'v0.8.0',
            'version' => '0.8.0.0',
            'reference' => '074a650c682e6cdf31a20caffaf0d820ab24acdb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/orm',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/scheduler' => array(
            'pretty_version' => 'v0.3.0',
            'version' => '0.3.0.0',
            'reference' => '27c1879e56151e62969c08f0822a78afb3ed59e5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/scheduler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/sql' => array(
            'pretty_version' => 'v0.9.1',
            'version' => '0.9.1.0',
            'reference' => 'ab1ac85ae3e594ce8de33da0ddfde9c2e0d8dc12',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/sql',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/stdlib' => array(
            'pretty_version' => 'v0.15.1',
            'version' => '0.15.1.0',
            'reference' => 'e25f0bbaac710955e2f141d86bfcc8c1bc0ec4d5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/stdlib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/validator' => array(
            'pretty_version' => 'v1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'd834f00ea0cb774ca37533ecafa8ae86b49d9b5f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/validator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ipl/web' => array(
            'pretty_version' => 'v0.13.1',
            'version' => '0.13.1.0',
            'reference' => 'f387e92504d7a03bb857d1aee9b7410e06dd065d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ipl/web',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mtdowling/cron-expression' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '^1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.1',
            'version' => '1.1.0.0',
            'reference' => 'cb6ce4845ce34a8ad9e68117c10ee90a29919eba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/collection' => array(
            'pretty_version' => '2.1.1',
            'version' => '2.1.1.0',
            'reference' => '344572933ad0181accbf4ba763e85a0306a8c5e2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/collection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/uuid' => array(
            'pretty_version' => '4.9.2',
            'version' => '4.9.2.0',
            'reference' => '8429c78ca35a09f27565311b98101e2826affde0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/uuid',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/event-loop' => array(
            'pretty_version' => 'v1.6.0',
            'version' => '1.6.0.0',
            'reference' => 'ba276bda6083df7e0050fd9b33f66ad7a4ac747a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/event-loop',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'react/promise' => array(
            'pretty_version' => 'v2.11.0',
            'version' => '2.11.0.0',
            'reference' => '1a8460931ea36dc5c76838fec5734d55c88c6831',
            'type' => 'library',
            'install_path' => __DIR__ . '/../react/promise',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rhumsaa/uuid' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '4.9.2',
            ),
        ),
        'simshaun/recurr' => array(
            'pretty_version' => 'v5.0.3',
            'version' => '5.0.3.0',
            'reference' => '7b136768d64f257065e38a804ee6d2f9af6ba6d1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../simshaun/recurr',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php83' => array(
            'pretty_version' => 'v1.36.0',
            'version' => '1.36.0.0',
            'reference' => '3600c2cb22399e25bb226e4a135ce91eeb2a6149',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php83',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php84' => array(
            'pretty_version' => 'v1.36.0',
            'version' => '1.36.0.0',
            'reference' => '88486db2c389b290bf87ff1de7ebc1e13e42bb06',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php84',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wikimedia/less.php' => array(
            'pretty_version' => 'v3.2.1',
            'version' => '3.2.1.0',
            'reference' => '0d5b30ba792bdbf8991a646fc9c30561b38a5559',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wikimedia/less.php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
